prefix="/usr"
datadir="/usr/share"
localedir=datadir+"/locale"
pkgdatadir="/usr/share/mozo"
PACKAGE="mozo"
VERSION="1.22.0"
GETTEXT_PACKAGE="mozo"
